@@ -12,6 +12,7 @@ from .jubeat_analyser import (
     load_mono_column,
 )
 from .konami import dump_eve, dump_jbsq, load_eve, load_jbsq
+from .malody import dump_malody, load_malody
 from .memon import (
     dump_memon_0_1_0,
     dump_memon_0_2_0,
@@ -25,6 +26,7 @@ from .typing import Dumper, Loader
 LOADERS: Dict[Format, Loader] = {
     Format.EVE: load_eve,
     Format.JBSQ: load_jbsq,
+    Format.MALODY: load_malody,
     Format.MEMON_LEGACY: load_memon_legacy,
     Format.MEMON_0_1_0: load_memon_0_1_0,
     Format.MEMON_0_2_0: load_memon_0_2_0,
@@ -37,6 +39,7 @@ LOADERS: Dict[Format, Loader] = {
 DUMPERS: Dict[Format, Dumper] = {
     Format.EVE: dump_eve,
     Format.JBSQ: dump_jbsq,
+    Format.MALODY: dump_malody,
     Format.MEMON_LEGACY: dump_memon_legacy,
     Format.MEMON_0_1_0: dump_memon_0_1_0,
     Format.MEMON_0_2_0: dump_memon_0_2_0,
